@@ -19,7 +19,7 @@ checkOnlyNAs <- function(x, msg){
 basicHM <- aheatmap
 
 checkPlot <- function(...){
-	if( isCRANcheck() ) return()
+	if( isCHECK() ) return()
 	pkgmaker::checkPlot(...)
 }
 
